[![pipeline status](https://gitlab.com/martincollado.com/i2p-python/badges/master/pipeline.svg)](https://gitlab.com/martincollado.com/i2p-python/commits/master)
[![coverage report](https://gitlab.com/martincollado.com/i2p-python/badges/master/coverage.svg)](https://gitlab.com/martincollado.com/i2p-python/commits/master)
[![Documentation Status](https://readthedocs.org/projects/i2p-python/badge/?version=latest)](http://i2p-python.readthedocs.io/es/latest/?badge=latest)

HRL From Idea to Production Tutorial
====================================

Este reposotorio existe coo prueba de concepto y demostración del trabajo en proyectos de
desarrollo de software, basado en metodologias de trabajo tipo TDD (Test Driven Development).

Tareas
------

- Terminar de programar todos los metodos de las operaciones solicitadas.
- Crear y comprobar todos los tests


Licencia
--------

Se trata de software libre y sin restricciones lanzado al dominio público.

Cualquier persona es libre de copiar, modificar, publicar, usar, compilar, vender o
distribuir este software, ya sea en forma de código fuente o como un
binario, para cualquier fin, comercial o no comercial, y por cualquier
medio.
